/*
 * Copyright (C) 2010 FUJITSU LIMITED
 */

package com.fujitsu.interstage.javaee.admin.event;


import com.sun.corba.ee.impl.folb.EJBDispatchException;
import com.sun.corba.ee.impl.folb.InitialIiopDispatchService;
import com.sun.ejb.containers.EjbIiopServerRequestInterceptor;
import com.sun.enterprise.admin.event.AdminEventListenerException;
import com.sun.enterprise.admin.event.RRPersistenceHelper;
import com.sun.enterprise.config.serverbeans.ServerTags;

/**
 * Listener impl that handle iiop-load-balance element events
 * 
 */
public class IiopLBChangeEventListenerImpl implements IiopLBChangeEventListener {
    private static final String CREATE_EJB_DISPATCH="createejbdispatchtarget";
    private static final String DELETE_EJB_DISPATCH="deleteejbdispatchtarget";
    private static final InitialIiopDispatchService eds = InitialIiopDispatchService.getInstance();
    
    /**
     * process iiopLBChangeEvent .
     * @throws AdminEventListenerException when the listener is unable to
     *         process the event.
     */
    public void iiopLBChangeChanged(IiopLBChangeEvent event)
            throws AdminEventListenerException {
        String attrName = event.getAttrName();
        String value = event.getNewAttrValue();
        String dispatcherTargetName = event.getTargetName();
        if (ServerTags.METHOD.equals(attrName)||ServerTags.OR_FAILOVER.equals(attrName)) {
            RRPersistenceHelper helper = new RRPersistenceHelper();
            helper.setRestartRequired(event.getInstanceName(), true);
        } else if (ServerTags.EJB_DISPATCH_TARGET_LOG.equals(attrName)) {
            InitialIiopDispatchService.setIsDispatchTargetLog(getBoolean(value));
        } else if (ServerTags.EJB_REQUEST_DISPATCH_LOG.equals(attrName)) {
            InitialIiopDispatchService.setIsDispatchRequestLog(getBoolean(value));
        } else if(CREATE_EJB_DISPATCH.equals(attrName)) {
            if(eds != null){
                try {
                    eds.addTargetCluster(dispatcherTargetName);
                } catch (EJBDispatchException e) {
                    e.printStackTrace();
                }
            }
        } else if(DELETE_EJB_DISPATCH.equals(attrName)) {
            if(eds != null){
                try {
                    eds.deleteTargetCluster(dispatcherTargetName);
                } catch (EJBDispatchException e) {
                    e.printStackTrace();
                }
            }
        }
            
    }
    
    /**
     * Convert value to boolean.
     * @param value
     * @return TRUE: "yes,on,1" in lower case, or "true" both lower case and capital
     * FALSE: not in the situation of TRUE.
     */
    private boolean getBoolean(String value){
        if(value == null || value.trim().equals("")){
            return false;
        }
        
        if("true".equalsIgnoreCase(value) || 
            "1".equals(value) ||
            "yes".equals(value) ||
            "on".equals(value)){
            return true;
        }else{
            return false;
        }
    }
}
