/*
 * Copyright (C) 2010 FUJITSU LIMITED
 */

package com.sun.corba.ee.impl.folb;

import java.io.IOException;
import java.net.Socket;
import java.rmi.Remote;
import java.rmi.RemoteException;
import java.util.ArrayList;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.logging.Level;
import java.util.logging.Logger;

import javax.rmi.PortableRemoteObject;
import javax.rmi.CORBA.Tie;

import org.omg.CORBA.CompletionStatus;
import org.omg.CORBA.LocalObject;
import org.omg.CORBA.OBJ_ADAPTER;
import org.omg.CORBA.ORB;
import org.omg.CORBA.Policy;
import org.omg.CosNaming.NameComponent;
import org.omg.CosNaming.NamingContext;
import org.omg.CosNaming.NamingContextHelper;
import org.omg.PortableInterceptor.ServerRequestInfo;
import org.omg.PortableServer.ForwardRequest;
import org.omg.PortableServer.LifespanPolicyValue;
import org.omg.PortableServer.POA;
import org.omg.PortableServer.RequestProcessingPolicyValue;
import org.omg.PortableServer.Servant;
import org.omg.PortableServer.ServantLocator;
import org.omg.PortableServer.ServantRetentionPolicyValue;
import org.omg.PortableServer.ServantLocatorPackage.CookieHolder;

import com.fujitsu.interstage.javaee.admin.InstanceStatusInfo;
import com.sun.corba.ee.impl.orbutil.ORBConstants;
import com.sun.corba.ee.impl.orbutil.ORBUtility;
import com.sun.corba.ee.spi.legacy.connection.Connection;
import com.sun.corba.ee.spi.legacy.interceptor.RequestInfoExt;
import com.sun.corba.se.impl.util.SUNVMCID;
import com.sun.enterprise.admin.event.InstanceStatusEvent;
import com.sun.enterprise.admin.event.InstanceStatusEventListener;
import com.sun.enterprise.admin.util.JMXConnectorConfig;
import com.sun.enterprise.config.ConfigContext;
import com.sun.enterprise.config.ConfigException;
import com.sun.enterprise.config.serverbeans.Cluster;
import com.sun.enterprise.config.serverbeans.ClusterHelper;
import com.sun.enterprise.config.serverbeans.Config;
import com.sun.enterprise.config.serverbeans.ConfigAPIHelper;
import com.sun.enterprise.config.serverbeans.DisabledTargetInstance;
import com.sun.enterprise.config.serverbeans.EjbDispatchTarget;
import com.sun.enterprise.config.serverbeans.IiopListener;
import com.sun.enterprise.config.serverbeans.IiopLoadBalance;
import com.sun.enterprise.config.serverbeans.IiopService;
import com.sun.enterprise.config.serverbeans.NodeAgent;
import com.sun.enterprise.config.serverbeans.NodeAgentHelper;
import com.sun.enterprise.config.serverbeans.PropertyResolver;
import com.sun.enterprise.config.serverbeans.Server;
import com.sun.enterprise.config.serverbeans.ServerHelper;
//import com.sun.enterprise.ee.admin.mbeanapi.NodeAgentMBean;
//import com.sun.enterprise.ee.admin.proxy.NodeAgentProxy;
import com.sun.enterprise.server.ApplicationServer;
import com.sun.enterprise.server.ServerContext;
import com.sun.enterprise.util.ORBManager;

/**
 * This class consists of : - Remote interface - Impl of the Remote interface -
 * ServantLocator
 * 
 * This is needed for setting the information about target server instance.
 */
public class InitialIiopDispatchService {

    private static final String IIOP_URL = "iiop:1.2@";
    private static final String CORBALOC = "corbaloc:";
    private static final String DAS_INSTANCE_NAME = "server";
    private static final String EJB_DISPATCHER = "ejb-dispatch";
    private static final String GMS = "gms";
    private static final String SSL = "SSL";
    private static Object tableLock = new Object();
    private static InitialIiopDispatchService dispatcher = null;
    private static Logger _logger = null;
    private static boolean isDispatchTargetLog = false;
    private static boolean isDispatchRequestLog = false;
    private static int updateThreadNum = 0;
    private static final String REQUEST_TYPE_SERVICE = "SERVICE";
    private static final String REQUEST_TYPE_EJB = "EJB";
    
    private boolean isInitialized = false;
    private boolean isDispatcher = false;
    private ConfigContext configCtx = null;
    
    private String myNodeAgentName = null;
    // already disabled instances before starting dispatcher
    // key: disabled instanceName; value: cluster name
    private Map<String,String> oldDisabledInstances = new HashMap<String,String>();

    // all target cluster name
    private List<String> targetClusterName = new ArrayList<String>();

    // adapter and cluster hashtable. key:adapter name value:cluster name
    private HashMap<String, TargetClusterInfo> adapterClusterHash = new HashMap<String, TargetClusterInfo>();

    // running instance list. key: cluster name value: instances list
    private Hashtable<String, LinkedList<TargetInstanceInfo>> clusterInstancesHash = new Hashtable<String, LinkedList<TargetInstanceInfo>>();

    // all instances list. key: instance name value: instance info
    private HashMap<String, TargetInstanceInfo> allTargetInstances = new HashMap<String, TargetInstanceInfo>();

    private InstanceStatusEventQueue queue = new InstanceStatusEventQueue();
    private InstanceStatusEventListener iseListener = null;
 
    static {
        String loggerName = "javax.enterprise.system.core.naming";
        String loggerResourceBundleName = "com.sun.logging.enterprise.system.core.naming.LogStrings";
        _logger = Logger.getLogger(loggerName, loggerResourceBundleName);
        updateThreadNum = 3;

    }

    public static synchronized InitialIiopDispatchService getInstance() {
        return dispatcher;
    }

    public static void setIsDispatchTargetLog(boolean value){
        isDispatchTargetLog = value;
    }
    
    public static void setIsDispatchRequestLog(boolean value){
        isDispatchRequestLog = value;
    }
    
    /**
     * Constructor of Iiop Dispatch Service.
     * 
     * @param orb
     * @throws IOException
     */
    public InitialIiopDispatchService(ORB orb) {

        _logger.fine("InitialIiopDispatchService:Bind INITIAL_IDS to CosNaming.");
        bindName(orb);

        // Retrieve the definition value from domain.xml.
        try {
            init();
        } catch (ConfigException e) {
            _logger.log(Level.SEVERE, "ejbd.initialize.error", e);
            return;
        } catch (IOException e) {
            _logger.log(Level.SEVERE, "ejbd.initialize.error", e);
            return;
        }

        if (isDispatcher) {
            // get and init dispatch targets
            loadDispathTargetClusters();
            
            // register runtime MBean DispatcherInfoMBean.
            // it is used for disable, enable, list ejb dispatch target
            // operation
            com.sun.enterprise.ManagementObjectManager mgmtObjManager = com.sun.enterprise.Switch
                    .getSwitch().getManagementObjectManager();
            mgmtObjManager.registerDispatcherInfo();

            // register InstanceStatusEventListener, in order to get latest
            // instance status from nodeAgent
            iseListener = new InstanceStatusEventListenerImpl();

            // TODO AdminEventListenerRegistry don't has
            // addInstaceStatusEventListener() method yet 2010/11/16
            // it will be done when nodeAgent service development finished.
            // AdminEventListenerRegistry.addInstaceStatusEventListener(iseListener);
           
            isInitialized = true;
            dispatcher = this;
            
            for(int i = 0; i < updateThreadNum; i++){
                TargetUpdateProcessorThread t = new TargetUpdateProcessorThread();
                t.start();
            }
        }


    }

    
    /**
     * Is an EJB Dispatcher or not.
     * @param context
     * @return
     */
    public static boolean isEjbDispatcher(ServerContext serverCtx){
        if(serverCtx == null){
            return false;
        }

        try {
            Cluster cluster = ClusterHelper.getClusterForInstance(serverCtx.getConfigContext(),
                    serverCtx.getInstanceName());
            IiopLoadBalance iiopLB = cluster.getIiopLoadBalance();
            String lbMethod = iiopLB.getMethod();
            if (lbMethod != null && EJB_DISPATCHER.equals(lbMethod.trim())) {
                return true;
            }
        } catch (ConfigException e) {
            e.printStackTrace();
            return false;
        }
        return false;
    }
    
    /**
     * Is using GroupManageService to load balance and fail-over or not.
     * @param serverCtx
     * @return true: if using GMS; false: if not using GMS.
     */
    public static boolean isGMS(ServerContext serverCtx){
        if(serverCtx == null){
            return false;
        }

        try {
            Cluster cluster = ClusterHelper.getClusterForInstance(serverCtx.getConfigContext(),
                    serverCtx.getInstanceName());
            IiopLoadBalance iiopLB = cluster.getIiopLoadBalance();
            String lbMethod = iiopLB.getMethod();
            if (lbMethod != null && GMS.equals(lbMethod.trim())) {
                return true;
            }
        } catch (ConfigException e) {
            e.printStackTrace();
            return false;
        }
        return false;
    }
    
    
    private void init() throws ConfigException, IOException {

        _logger.log(Level.INFO, "ejbd.initialize");
        ServerContext serverCtx = ApplicationServer.getServerContext();
        configCtx = serverCtx.getConfigContext();

        isDispatcher = isEjbDispatcher(serverCtx);
        if(!isDispatcher){
            isInitialized = true;
            _logger.fine("InitialIiopDispatchService.init: It isn't an EJB Dispatcher.");
            return;
        }

        // get iiop-load-banlance config info from domain.xml
        String instanceName = serverCtx.getInstanceName();
        Cluster cluster = ClusterHelper.getClusterForInstance(configCtx,
                instanceName);
        IiopLoadBalance iiopLB = cluster.getIiopLoadBalance();
        if (iiopLB != null) {
            isDispatchTargetLog = iiopLB.isEjbDispatchTargetLog();
            isDispatchRequestLog = iiopLB.isEjbRequestDispatchLog();
            EjbDispatchTarget[]dispatchTargets = iiopLB.getEjbDispatchTarget();
            if (dispatchTargets != null) {
                for (EjbDispatchTarget target : dispatchTargets) {
                    targetClusterName.add(target.getName());
                }
            }
            // get disabled instances from domain.xml
            DisabledTargetInstance[] disabledInst = iiopLB.getDisabledTargetInstance();
            if(disabledInst != null){
                for(int i = 0; i < disabledInst.length; i++){
                    DisabledTargetInstance di = disabledInst[i];
                    oldDisabledInstances.put(di.getName(), di.getClustername());
                }
            }

        }else{
            return;
        }

        Server serverObj = ServerHelper.getServerByName(configCtx, instanceName);
        myNodeAgentName = serverObj.getNodeAgentRef();
    }

    /**
     * Load ejb dispatch target clusters from domain.xml.
     */
    private void loadDispathTargetClusters() {

        if (targetClusterName == null) {
            return;
        }

        for (int i = 0; i < targetClusterName.size(); i++) {
            String clusterName = targetClusterName.get(i);

            try {
                addDispatchTargetCluster(clusterName, true);
            } catch (ConfigException e) {
                _logger.log(Level.SEVERE, "ejbd.acquire.cluster.info.failed",
                        clusterName);
                return;
            }
        }
        
        // connect to NodeAgent to get running instances list
        // if instance is started, 
        // then connect to instance to get references and adapter names
        updateInstanceStatus();

    }

    private void addDispatchTargetCluster(String clusterName, boolean isInit)
            throws ConfigException{
        
        ServerContext serverCtx = ApplicationServer.getServerContext();
        configCtx = serverCtx.getConfigContext();
        Server[] servers = ServerHelper.getServersInCluster(configCtx,
                clusterName);
        if (servers == null) {
            return;
        }
        for (int j = 0; j < servers.length; j++) {
            Server server = servers[j];
            String nodeAgentName = server.getNodeAgentRef();
            String instanceName = server.getName();
            if (!myNodeAgentName.equals(nodeAgentName)) {
                _logger
                        .fine("InitialIiopDispatchService.addDispatchTargetCluster: can't add instance "
                                + instanceName
                                + ". Because it has different nodeagent nodeagentName="
                                + nodeAgentName);
                continue;
            }
            // get instance iiop communication host and port
            String corbalocUrl = getConnectURL(configCtx, instanceName);
            addTargetInstance(instanceName, corbalocUrl, clusterName, isInit);
        }
    }

    private void addTargetInstance(String instanceName, String corbalocUrl,
            String clusterName, boolean isInit) throws ConfigException{

        // prepare instance info
        TargetInstanceInfo insInfo = new TargetInstanceInfo();
        insInfo.setInstanceName(instanceName);
        insInfo.setClusterName(clusterName);
        insInfo.setCorbalocUrl(corbalocUrl);
        
        // all of instance are set to STOPPED, when Dispatcher init.
        // Then get instance running status from NodeAgent, 
        // and change target instances' status.
        insInfo.setRunningStatus(TargetInstanceInfo.LIFE_STATUS_STOPPED);
        
        // set dispatch status "enable" or "disable"
        if(oldDisabledInstances.containsKey(instanceName)){
            // insInfo has same cluterName with oldDisabled, set to "disable"
            if(oldDisabledInstances.get(instanceName).equals(clusterName)){
                insInfo.setDispatchStatus(TargetInstanceInfo.DISPATCH_STATUS_DISABLE);
            }else{
                // insInfo has different clusterName with oldDisable, set to "enable"
                insInfo.setDispatchStatus(TargetInstanceInfo.DISPATCH_STATUS_ENABLE);
            }
        }else{
            insInfo.setDispatchStatus(TargetInstanceInfo.DISPATCH_STATUS_ENABLE);
        }
        
        synchronized (tableLock) {
            allTargetInstances.put(instanceName, insInfo);
            // connect to instance to get reference and adapter name
            if(!isInit){
                _addAdapter(insInfo,"add");
            }
        }
    }

    private Map<String, InstanceStatusInfo> testNA(){
        Map<String, InstanceStatusInfo> list = new HashMap<String, InstanceStatusInfo>();
        InstanceStatusInfo info = new InstanceStatusInfo();
        info.setClusterName("cluster2");
        info.setInstanceName("i3");
        info.setStatus(TargetInstanceInfo.LIFE_STATUS_STARTED);
        list.put("i3", info);
        
        InstanceStatusInfo info2 = new InstanceStatusInfo();
        info2.setClusterName("cluster2");
        info2.setInstanceName("i4");
        info2.setStatus(TargetInstanceInfo.LIFE_STATUS_STARTED);
        list.put("i4", info2);
        
        return list;
    }
    
    
    /**
     * Connect to NodeAgent then 
     * update every Target instance's referenc and adaptername
     */
    private void updateInstanceStatus(){
        ServerContext context = ApplicationServer.getServerContext();
        NodeAgent agent = null;
        try {
            agent = NodeAgentHelper.getNodeAgentForServer(context.getConfigContext(),context.getInstanceName());
        } catch (ConfigException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }
//        NodeAgentMBean agentMBean =  NodeAgentProxy.getNodeAgentProxy(agent.getName());
//        Map<String, InstanceStatusInfo> instanceStatusInfos = agentMBean.getInstanceStatusInfosForEjbDispatcher();
        Map<String, InstanceStatusInfo> instanceStatusInfos = this.testNA();
                       
        if(allTargetInstances == null ){
            return;
        }
              
        synchronized (tableLock) {
            Iterator<String> keys = allTargetInstances.keySet().iterator();
            while(keys.hasNext()){               
                String instanceName = keys.next();
                TargetInstanceInfo info = allTargetInstances.get(instanceName);          
                
                InstanceStatusInfo isi = instanceStatusInfos.get(instanceName);               
                // "isi == null" means target instance is not started
                if(isi == null){
                    continue;
                }
                
                // do not connect disabled instance
                if(TargetInstanceInfo.DISPATCH_STATUS_DISABLE.equals(info.getDispatchStatus())){
                    info.setRunningStatus(isi.getStatus());
                    continue;
                }
                
                if(TargetInstanceInfo.LIFE_STATUS_STARTED.equals(isi.getStatus())){
                    _addAdapter(info, "add");
                }else{
                    // instance status is not "running", it must be hung up
                    info.setRunningStatus(TargetInstanceInfo.LIFE_STATUS_NO_RESPONSE);
                } // end if 
                
            } // end while
        } // end synchronized
    }
    
    
    private List<IiopSocketInformation> getHostPortListFromInstance(
            String instanceName, IiopListener[] serverlisteners)
            throws ConfigException {
        String hostName = getHostNameForServerInstance(instanceName);
        List<IiopSocketInformation> hostPortList = new ArrayList<IiopSocketInformation>();
        for (IiopListener listener : serverlisteners) {
            if (!listener.getId().startsWith(SSL)) {
                String strPort = getResolvedPort(listener, instanceName);
                int port = Integer.parseInt(strPort);
                if (hostName == null || "".equals(hostName.trim())) {
                    hostName = listener.getAddress();
                }
                IiopSocketInformation isi = new IiopSocketInformation();
                isi.setHost(hostName);
                isi.setPort(port);
                hostPortList.add(isi);
            }
        }

        return hostPortList;
    }

    public static Hashtable<String, org.omg.CORBA.Object> getAdapterReferenceFromInstance(
            String corbalocUrl) throws RemoteException, Exception {
        InitialIiopDispatchService.InitialIDS targetIDS = getIDS(corbalocUrl);
        if (targetIDS == null) {
            _logger.log(Level.WARNING,
                            "InitialIiopDispatchService.getAdapterReferenceFromInstance:" +
                            " Can not get InitialIDS. Connect to "
                                    + corbalocUrl + " error.");
            // TODO return null?
            return new Hashtable<String, org.omg.CORBA.Object>();
        }
        return targetIDS.getAllAdapterInformation();
    }


    /**
     * Returns ip address from node agent by instance name or null if Exception
     */
    private String getHostNameForServerInstance(String serverName) {
        String host = "";
        try {
            JMXConnectorConfig info = ServerHelper.getJMXConnectorInfo(
                    configCtx, serverName);
            host = info.getHost();
            return host;
        } catch (Throwable e) {
            _logger.log(Level.SEVERE, "ejbd.acquire.instance.info.error", e);
            return host;
        }
    }

    /**
     * Gets the correct resolved value for the specific instance Without this
     * routine, config context resolves the value to the current running
     * instance
     */
    private String getResolvedPort(IiopListener l, String server)
            throws ConfigException {
        String rawPort = l.getRawAttributeValue("port");
        PropertyResolver pr = new PropertyResolver(configCtx, server);
        return pr.resolve(rawPort);
    }

    private String getConnectURL(ConfigContext ctx, String instanceName){
        String corbalocUrl = null;
        try {
            Server server = ServerHelper.getServerByName(ctx, instanceName);
            
            String configRef = server.getConfigRef();
            Config config = ConfigAPIHelper.getConfigByName(ctx,
                    configRef);
            IiopService iiopService = config.getIiopService();
            IiopListener[] serverlisteners = iiopService.getIiopListener();
            List<IiopSocketInformation> hostPortList = getHostPortListFromInstance(
                    instanceName, serverlisteners);
            corbalocUrl = getCorbalocURL(hostPortList);
        } catch (ConfigException e) {
            e.printStackTrace();
        }
        return corbalocUrl;
    }
    
    private String getCorbalocURL(List<IiopSocketInformation> list) {

        String corbalocURL = "";
        if (list == null || list.size() == 0) {
            return corbalocURL;
        }
        // convert list into corbaloc url
        for (int i = 0; i < list.size(); i++) {
            if (corbalocURL.equals("")) {
                corbalocURL = IIOP_URL
                        + ((IiopSocketInformation) list.get(i)).getHost()
                                .trim() + ":"
                        + ((IiopSocketInformation) list.get(i)).getPort();
            } else {
                corbalocURL = corbalocURL
                        + ","
                        + IIOP_URL
                        + ((IiopSocketInformation) list.get(i)).getHost()
                                .trim() + ":"
                        + ((IiopSocketInformation) list.get(i)).getPort();
            }
        }
        return CORBALOC + corbalocURL.trim();
    }

    public static InitialIiopDispatchService.InitialIDS getIDS(
            String corbalocURL){
        InitialIiopDispatchService.InitialIDS ids = null;

        try {
            org.omg.CORBA.Object ref = ORBManager.getORB().string_to_object(
                    corbalocURL);
            NamingContext nctx = NamingContextHelper.narrow(ref);
            NameComponent[] path = { new NameComponent("INITIAL_IDS", "") };
            ids = (InitialIiopDispatchService.InitialIDS) PortableRemoteObject
                    .narrow(nctx.resolve(path),
                            InitialIiopDispatchService.InitialIDS.class);
        } catch (Exception e) {
            _logger.log(Level.SEVERE,
                    "InitialIiopDispatchService.InitialIDS getIDS error. corbalocURL="
                            + corbalocURL);
            e.printStackTrace();
        }
        return ids;
    }

    public void bindName(ORB orb) {
        try {
            POA rootPOA = (POA) orb
                    .resolve_initial_references(ORBConstants.ROOT_POA_NAME);

            Policy[] arr = new Policy[] {
                    rootPOA
                            .create_servant_retention_policy(ServantRetentionPolicyValue.NON_RETAIN),
                    rootPOA
                            .create_request_processing_policy(RequestProcessingPolicyValue.USE_SERVANT_MANAGER),
                    rootPOA
                            .create_lifespan_policy(LifespanPolicyValue.TRANSIENT) };

            POA poa = rootPOA.create_POA(
                    ORBConstants.INITIAL_IIOP_DISPATCH_SERVICE, null, arr);

            InitialIDSServantLocator servantLocator = new InitialIDSServantLocator(
                    orb);
            poa.set_servant_manager(servantLocator);
            poa.the_POAManager().activate();

            byte[] id = new byte[] { 1, 2, 3 };
            org.omg.CORBA.Object provider = poa.create_reference_with_id(id,
                    servantLocator.getType());

            // put object in NameService
            org.omg.CORBA.Object objRef = orb
                    .resolve_initial_references("NameService");
            NamingContext ncRef = NamingContextHelper.narrow(objRef);
            NameComponent nc = new NameComponent(
                    ORBConstants.INITIAL_IIOP_DISPATCH_SERVICE, "");
            NameComponent path[] = { nc };
            ncRef.rebind(path, provider);
        } catch (Exception e) {
            dprint("Exception in InitialGroupInfoService.bindName()==> ", e);
        }
    }

    public void disableTargetInstance(String instanceName)
            throws EJBDispatchException {
        if (!isInitialized) {
            return;
        }

        synchronized (tableLock) {
            TargetInstanceInfo instanceInfo = allTargetInstances
                    .get(instanceName);
            if (instanceInfo != null) {
                // set dispatch stauts to disabled
                instanceInfo.setDispatchStatus(TargetInstanceInfo.DISPATCH_STATUS_DISABLE);

                // remove instance info from cluster instance hashtable
                String clusterName = instanceInfo.getClusterName();
                LinkedList<TargetInstanceInfo> instanceList = clusterInstancesHash
                        .get(clusterName);
                if (instanceList != null) {
                    instanceList.remove(instanceInfo);
                }
                
                // decrease application count in adapterClusterHash
                Hashtable<String, org.omg.CORBA.Object> references = instanceInfo.getAllReferences();
                Iterator<String> it = references.keySet().iterator();
                while(it.hasNext()){
                    String adapter = it.next();
                    if(references.get(adapter).equals(clusterName)){
                        (adapterClusterHash.get(adapter)).decrease();
                    }
                }             
                
            }else {
                try {
                    Cluster cluster = ClusterHelper.getClusterForInstance(configCtx,
                            instanceName);
                    String clusterName = cluster.getName();
                                                           
                    if(targetClusterName.contains(clusterName)){
                        // is dispatcher target, add to allTargetInstances
                        TargetInstanceInfo info = new TargetInstanceInfo();
                        info.setClusterName(clusterName);
                        info.setInstanceName(instanceName);
                        info.setDispatchStatus(TargetInstanceInfo.DISPATCH_STATUS_ENABLE);
                        info.setRunningStatus(TargetInstanceInfo.LIFE_STATUS_STOPPED);
                        info.setCorbalocUrl(getConnectURL(configCtx, instanceName));
                        allTargetInstances.put(instanceName, info);
                    }else{
                        throw new EJBDispatchException("ejbd.operator.not.target");
                    }
                } catch (ConfigException e) {
                    e.printStackTrace();
                    throw new EJBDispatchException("ejbd.operator.not.target");
                }
            }

        }

        if (isDispatchTargetLog) {
            _logger.log(Level.INFO, "ejbd.target.disable", instanceName);
        }

    
    } // disableTargetInstance

    public void enableTargetInstance(String instanceName)
            throws EJBDispatchException {

        if (!isInitialized) {
            return;
        }
       
        TargetInstanceInfo instanceInfo = null;
        synchronized (tableLock) {
            instanceInfo = allTargetInstances.get(instanceName);
            if(instanceInfo != null){
                instanceInfo.setDispatchStatus(TargetInstanceInfo.DISPATCH_STATUS_ENABLE);
                String runningStatus = instanceInfo.getRunningStatus();
                if (TargetInstanceInfo.LIFE_STATUS_STOPPED.equals(runningStatus)
                        || TargetInstanceInfo.LIFE_STATUS_NO_RESPONSE.equals(runningStatus)) {
                    return ;
                }                
                _addAdapter(instanceInfo,"enable");
            }else{ 
                // instanceInfo is null means: 
                // instance is not target instance or 
                // is a new created but not started instance in dispatcher target cluster
                try {
                    Cluster cluster = ClusterHelper.getClusterForInstance(configCtx,
                            instanceName);
                    String clusterName = cluster.getName();
                                                           
                    if(targetClusterName.contains(clusterName)){
                        // is dispatcher target, add to allTargetInstances
                        TargetInstanceInfo info = new TargetInstanceInfo();
                        info.setClusterName(clusterName);
                        info.setInstanceName(instanceName);
                        info.setDispatchStatus(TargetInstanceInfo.DISPATCH_STATUS_DISABLE);
                        info.setRunningStatus(TargetInstanceInfo.LIFE_STATUS_STOPPED);
                        info.setCorbalocUrl(getConnectURL(configCtx, instanceName));
                        allTargetInstances.put(instanceName, info);
                    }else{
                        throw new EJBDispatchException("ejbd.operator.not.target");
                    }
                } catch (ConfigException e) {
                    e.printStackTrace();
                    throw new EJBDispatchException("ejbd.operator.not.target", e);
                } // catch           
            }           
        }
        
        // write enable log
        if (isDispatchTargetLog && instanceInfo != null) {
            Hashtable<String, org.omg.CORBA.Object> references = instanceInfo
                    .getAllReferences();
            if (references != null) {
                Enumeration<String> e = references.keys();
                while (e.hasMoreElements()) {
                    String adapterName = e.nextElement();
                    // TODO how to get interface name??
                    String interfaceName = "";
                    _logger.log(Level.INFO, "ejbd.target.enable", new Object[] {
                            instanceName, interfaceName, adapterName });
                }
            } else {
                _logger.log(Level.INFO, "ejbd.target.enable", new Object[] {
                        instanceName, "", "" });
            }

        }

    } // enableTargetInstance

    
    
    public Map<String,Map<String,String>> listTargetStatus(String targetCluster) throws EJBDispatchException{
        if(allTargetInstances == null){
            throw new EJBDispatchException("Noting to list.");
        }
        if(targetCluster == null || "".equals(targetCluster.trim())){
            return this.getAllTargetInstanceStatus();
        }else{
            return this.getTargetInstancesByCluster(targetCluster.trim());
        }
    }
    
    private Map<String,Map<String,String>> getAllTargetInstanceStatus(){
        Map<String,Map<String,String>> result = new HashMap<String,Map<String,String>>();
        
        synchronized (tableLock) {
            Iterator<String> keys = allTargetInstances.keySet().iterator();
            while (keys.hasNext()) {
                String instanceName = keys.next();
                TargetInstanceInfo info = allTargetInstances.get(instanceName);
                String clustrName = info.getClusterName();
                Map<String,String> existMap = result.get(clustrName);
                if(existMap == null){
                    existMap = new HashMap<String,String>();
                    result.put(clustrName, existMap);
                }
                String status = info.getInstanceName() + "/" + info.getRunningStatus();
                existMap.put(info.getInstanceName(), status);           
            }
        }   
        return result;
    }
    
    private Map<String,Map<String,String>> getTargetInstancesByCluster(String clusterName){
        Map<String,Map<String,String>> result = new HashMap<String,Map<String,String>>();
        if(clusterName == null || "".equals(clusterName.trim())){
            return result;
        }
        
        synchronized (tableLock) {
            Iterator<String> keys = allTargetInstances.keySet().iterator();
            while (keys.hasNext()) {
                String instanceName = keys.next();
                TargetInstanceInfo info = allTargetInstances.get(instanceName);
                String tempClustrName = info.getClusterName();
                if(clusterName.equals(tempClustrName)){
                    Map<String,String> existMap = result.get(tempClustrName);
                    if(existMap == null){
                        existMap = new HashMap<String,String>();
                        result.put(tempClustrName, existMap);
                    }
                    String status = info.getInstanceName() + "/" + info.getRunningStatus();
                    existMap.put(info.getInstanceName(), status);     
                }
            }
        }   
        return result;
    }
 
    public void addTargetCluster(String clusterName) throws EJBDispatchException,
            EJBDispatchException {
        if (clusterName == null || "".equals(clusterName)) {
            throw new EJBDispatchException(
                    "The operator cluster can not be empty.");
        } else if (DAS_INSTANCE_NAME.equals(clusterName)) {
            throw new EJBDispatchException(
                    "Interstage Java EE Domain Administration Server can not be dispatch target.");
        } else if (clusterInstancesHash.containsKey(clusterName)) {
            throw new EJBDispatchException("The operator cluster "
                    + clusterName + " is already exist.");
        }

        try {
            _logger.fine("add a new target cluster=" + clusterName);

            synchronized (tableLock) {
                if (!targetClusterName.contains(clusterName)) {
                    targetClusterName.add(clusterName);
                }
            }
            addDispatchTargetCluster(clusterName, false);
        } catch (ConfigException e) {
            throw new EJBDispatchException(e);
        }

    }

    public void deleteTargetCluster(String clusterName)
            throws EJBDispatchException {
        if (clusterName == null || "".equals(clusterName)) {
            throw new EJBDispatchException(
                    "The operator cluster can not be empty.");
        } else if (DAS_INSTANCE_NAME.equals(clusterName)) {
            throw new EJBDispatchException("Interstage Java EE Domain Administration Server can not be dispatch target.");
        } else if (!targetClusterName.contains(clusterName)) {
            throw new EJBDispatchException("The operator cluster "
                    + clusterName + " is not dispatch target.");
        }

        _deleteAdapter(clusterName);

    } // deleteTargetCluster method
    
    
    private void _addAdapter(TargetInstanceInfo info, String operation) {

        // connect to instance to get ejb's adpatername and referece
        Hashtable<String,org.omg.CORBA.Object> adapterAndReferences = null;
        String instanceName = info.getInstanceName();
        try {
            _logger.log(Level.INFO, "ejbd.target.connect",instanceName);
            String url = info.getCorbalocUrl();
            if(url == null || "".equals(url.trim())){
                url = getConnectURL(configCtx, instanceName);
            }
            adapterAndReferences = getAdapterReferenceFromInstance(url);
            _logger.log(Level.INFO, "ejbd.target.connect.success",instanceName);
        } catch (RemoteException e) {                        
            _logger.log(Level.SEVERE, "ejbd.target.connect.error",e);
            info.setRunningStatus(TargetInstanceInfo.LIFE_STATUS_STOPPED);
            e.printStackTrace();
        } catch (Exception e) {
            _logger.log(Level.SEVERE, "ejbd.target.connect.error",e);
            info.setRunningStatus(TargetInstanceInfo.LIFE_STATUS_STOPPED);
            e.printStackTrace();
        }
        
        synchronized (tableLock) {
            TargetInstanceInfo tempInfo = allTargetInstances.get(instanceName);
            if (tempInfo != info) {
                allTargetInstances.put(instanceName, info);
            } 
            if (adapterAndReferences == null
                    || adapterAndReferences.size() == 0) {
                _logger
                        .log(Level.FINE,
                                "EJB Applications' adapter name and reference is empty.");
            } else {
                info.setAllReferences(adapterAndReferences);
                info.setRunningStatus(TargetInstanceInfo.LIFE_STATUS_STARTED);

                // set clusterInstancesHash
                LinkedList<TargetInstanceInfo> instanceList = clusterInstancesHash
                        .get(info.getClusterName());
                if (instanceList == null) {
                    instanceList = new LinkedList<TargetInstanceInfo>();
                    clusterInstancesHash.put(info.getClusterName(), instanceList);
                }
                instanceList.add(info);

                // set adapterClusterHash
                Enumeration<String> adapters = adapterAndReferences.keys();
                while (adapters.hasMoreElements()) {
                    String adapterName = adapters.nextElement();
                    TargetClusterInfo clusterInfo = adapterClusterHash
                            .get(adapterName);
                    if (clusterInfo == null) {
                        clusterInfo = new TargetClusterInfo(info
                                .getClusterName());
                        adapterClusterHash.put(adapterName, clusterInfo);
                    }
                    clusterInfo.increase();

                    if (isDispatchTargetLog) {
                        // TODO: how to get interface name??
                        String interfaceName = "";
                        String msgId = null;
                        if ("add".equalsIgnoreCase(operation)) {
                            msgId = "ejbd.target.add";
                        } else if ("enable".equalsIgnoreCase(operation)) {
                            msgId = "ejbd.target.enable";
                        }
                        _logger.log(Level.INFO, msgId, new Object[] {
                                instanceName, interfaceName, adapterName });
                    }
                } // end while

            }
        }                 

    }


    private void _deleteAdapter(String clusterName) {

        synchronized (tableLock) {
            // delete from targetClusterName
            targetClusterName.remove(clusterName);
            // delete from clusterInstancesHash
            clusterInstancesHash.remove(clusterName);

            // delete from adapter cluster Hashtable
            Iterator<String> e = adapterClusterHash.keySet().iterator();
            while (e.hasNext()) {
                String adapterName = (String) e.next();
                TargetClusterInfo value = adapterClusterHash.get(adapterName);
                if (value.getName().equals((clusterName))) {
                    int appCount = value.decrease();
                    if (appCount <= 0)
                        adapterClusterHash.remove(adapterName);
                }
            }

            // delete from allTargetInstance
            Iterator<String> insNames = allTargetInstances.keySet().iterator();
            while (insNames.hasNext()) {
                String instName = (String) insNames.next();
                TargetInstanceInfo info = allTargetInstances.get(instName);
                if (clusterName.equals(info.getClusterName())) {
                    allTargetInstances.remove(instName);
                    if (isDispatchTargetLog) {
                        _logger.log(Level.INFO, "ejbd.target.delete", instName);
                    }
                }
            }
        } // end of synchronized

    }

    /**
     * Select an appropriate instance for an EJB create operation.
     * 
     * @param adapterName
     * @return
     * @throws RemoteException
     */
    public void getNextRotation(ServerRequestInfo ri) throws org.omg.PortableInterceptor.ForwardRequest{
       
        Boolean isEjbCall = isEjbCall(ri);
        boolean requestLog = isDispatchRequestLog;
        String remoteHost = "";
        if (requestLog) { 
            Connection conn = ((RequestInfoExt) ri).connection();
            if (conn != null) {
                Socket socket = conn.getSocket();
                remoteHost = socket.getInetAddress().toString().substring(1);
            }
            String type = (isEjbCall ? REQUEST_TYPE_EJB : REQUEST_TYPE_SERVICE);
            _logger.log(Level.INFO, "ejbd.request.accept.log", new Object[] {
                    ri.request_id(), remoteHost, type, ri.target_most_derived_interface(),
                    ri.operation(), createApplicationInfo(ri.adapter_name()) });
        }

        // only dispatch ejb create operation
        if (!isEjbCall) {
            return;
        }
        
        String[] adapterName = ri.adapter_name();
        String name = adapterName[adapterName.length - 1];
        org.omg.CORBA.Object ref = null;

        synchronized (tableLock) {
            TargetClusterInfo cinfo = adapterClusterHash.get(name);
            if(cinfo == null){
                _logger.log(Level.SEVERE, "ejbd.target.not.exit", ri.target_most_derived_interface());
                //"vmcid: SUN  minor code: 999  completed: No");
                int minor = SUNVMCID.value + 999;
                throw new OBJ_ADAPTER(minor, CompletionStatus.COMPLETED_NO );
            }
            String clusterName = cinfo.getName();
            LinkedList<TargetInstanceInfo> instanceList = clusterInstancesHash
                    .get(clusterName);
            if (instanceList != null) {
                TargetInstanceInfo selectedInst = null;
                int instCount = instanceList.size();
                while(ref == null && instCount > 0){
                    // retrieves and remove first element
                    selectedInst = instanceList.poll();
                    // append selected element to the end
                    instanceList.add(selectedInst);  
                    ref = selectedInst.getAllReferences().get(name);
                    instCount --;
                }
                
                if (ref != null) {
                    if (isDispatchRequestLog) {
                        String type = (isEjbCall ? REQUEST_TYPE_EJB
                                : REQUEST_TYPE_SERVICE);
                        _logger.log(Level.INFO, "ejbd.request.dispatch.log",
                                new Object[] { ri.request_id(), remoteHost, selectedInst.getInstanceName(),
                                        type, ri.target_most_derived_interface(), ri.operation(),
                                        name });
                    }
                    throw new org.omg.PortableInterceptor.ForwardRequest(ref);
                }else{
                    _logger.log(Level.SEVERE, "ejbd.target.not.exit", ri.target_most_derived_interface());
                    //"vmcid: SUN  minor code: 999  completed: No");
                    int minor = SUNVMCID.value + 999;
                    throw new OBJ_ADAPTER(minor, CompletionStatus.COMPLETED_NO );
                }
            }else{
                _logger.log(Level.SEVERE, "ejbd.target.not.exit", ri.target_most_derived_interface());
                //"vmcid: SUN  minor code: 999  completed: No");
                int minor = SUNVMCID.value + 999;
                throw new OBJ_ADAPTER(minor, CompletionStatus.COMPLETED_NO );
            }
        }
    }
    
    private void dprint(String msg) {
        ORBUtility.dprint("InitialIiopDispatchService", msg);
    }

    private void dprint(String msg, Throwable t) {
        dprint(msg);
        dprint(t.toString());
    }
    
    public void startInstance(TargetInstanceInfo newInfo){
        if(newInfo == null)
            return;
        _addAdapter(newInfo, "add");
        
    }
    
    public void stopInstance(TargetInstanceInfo instInfo) {
        if (instInfo == null) {
            return;
        }
        String clusterName = instInfo.getClusterName();

        synchronized (tableLock) {
            
            TargetInstanceInfo tempInfo = allTargetInstances.get(instInfo.getInstanceName());
            tempInfo.setRunningStatus(TargetInstanceInfo.LIFE_STATUS_STOPPED);
            
            LinkedList<TargetInstanceInfo> list = clusterInstancesHash
                    .get(clusterName);
            if (list != null) {
                list.remove(instInfo);
            }
            
            // delete from adapter cluster Hashtable
            Iterator<String> e = adapterClusterHash.keySet().iterator();
            while (e.hasNext()) {
                String adapterName = (String) e.next();
                TargetClusterInfo value = adapterClusterHash.get(adapterName);
                if (value.getName().equals((clusterName))) {
                    int appCount = value.decrease();
                    if (appCount <= 0)
                        adapterClusterHash.remove(adapterName);
                }
            }
        }
    }
    
    
    public void hangInstance(TargetInstanceInfo info){
        if(info == null){
            return;
        }
        
        String clusterName = info.getClusterName();        
        LinkedList<TargetInstanceInfo> list = clusterInstancesHash
                .get(info.getClusterName());
        if (list != null) {
            list.remove(info);
        }
        
        // delete from adapter cluster Hashtable
        Iterator<String> e = adapterClusterHash.keySet().iterator();
        while (e.hasNext()) {
            String adapterName = (String) e.next();
            TargetClusterInfo value = adapterClusterHash.get(adapterName);
            if (value.getName().equals((clusterName))) {
                int appCount = value.decrease();
                if (appCount <= 0)
                    adapterClusterHash.remove(adapterName);
            }
        }
        
    }
    
    public interface InitialIDS extends Remote {

        public Hashtable<String, org.omg.CORBA.Object> getAllAdapterInformation()
                throws RemoteException;

    } // InitialIDS class

    public class InitialIDSImpl extends PortableRemoteObject implements
            InitialIDS {

        private ORB orb;

        public InitialIDSImpl(ORB orb) throws RemoteException {
            super();
            this.orb = orb;
        }

        public Hashtable<String, org.omg.CORBA.Object> getAllAdapterInformation()
                throws RemoteException {
            _logger.fine("Get EJB adapter name and reference from dispatch target instance.");
            IiopDispatchServiceClient idsc = IiopDispatchServiceClient
                    .getInstance();
            return idsc.getAllAdapterInformation();
        }

    } // InitialIDSImpl class

    public class InitialIDSServantLocator extends LocalObject implements
            ServantLocator {
        private Servant servant;
        private InitialIDSImpl impl = null;

        public InitialIDSServantLocator(ORB orb) {
            try {
                impl = new InitialIDSImpl(orb);
            } catch (Exception exc) {
                dprint("Exception in new InitialIDSServantLocator==> ", exc);
            }

            Tie tie = com.sun.corba.ee.spi.orb.ORB.class.cast(orb)
                    .getPresentationManager().getTie();
            tie.setTarget(impl);
            servant = Servant.class.cast(tie);
        }

        public String getType() {
            return servant._all_interfaces(null, null)[0];
        }

        public synchronized Servant preinvoke(byte[] oid, POA adapter,
                String operation, CookieHolder the_cookie)
                throws ForwardRequest {
            return servant;
        }

        public void postinvoke(byte[] oid, POA adapter, String operation,
                Object the_cookie, Servant the_servant) {
        }
    }
    

    class TargetUpdateProcessorThread extends Thread {
        private boolean running = true;

        TargetUpdateProcessorThread() {
        }

        public boolean isRunning() {
            return running;
        }

        public void setRunning(boolean running) {
            this.running = running;
        }

        @Override
        public void run() {
            while (running) {
                try {
                    Map<String, InstanceStatusInfo> runningInst = null;
                    
                    if (queue != null) {
                        runningInst = queue.getStatusMap();
                    }else{
                        System.out.println("xxxxxxxxxxxxxxxxxx qeue is null. sleep 10 seconds.");
                        Thread.sleep(10 * 1000);
                    }
                    // configCtx may be changed
                    ServerContext serverCtx = ApplicationServer.getServerContext();
                    configCtx = serverCtx.getConfigContext();
                    
                    // update instance info in all target instance hashtable
                    synchronized (tableLock) {
                        
                        // update every instances in allTargetInstances
                        Iterator<String> keys = allTargetInstances.keySet().iterator();
                        while (keys.hasNext()) {
                            String instanceName = keys.next();
                            TargetInstanceInfo targetInfo = allTargetInstances
                                    .get(instanceName);
                            InstanceStatusInfo statusInfo = runningInst
                                    .get(instanceName);

                            if (statusInfo == null) {
                                // instance is stopped
                                targetInfo
                                        .setRunningStatus(TargetInstanceInfo.LIFE_STATUS_STOPPED);
                                stopInstance(targetInfo);
                                continue;
                            }

                            String dispatchStauts = targetInfo
                                    .getDispatchStatus();
                            String oldRunning = targetInfo.getRunningStatus();
                            String newRunning = statusInfo.getStatus();

                            if (TargetInstanceInfo.DISPATCH_STATUS_ENABLE.equals(dispatchStauts)) {
                                if (TargetInstanceInfo.LIFE_STATUS_STARTED.equals(oldRunning)) {
                                    if (TargetInstanceInfo.LIFE_STATUS_STARTED.equals(newRunning)) {
                                        continue;
                                    } else if (TargetInstanceInfo.LIFE_STATUS_NO_RESPONSE.equals(newRunning)) {
                                        hangInstance(targetInfo);
                                    }
                                } else if (TargetInstanceInfo.LIFE_STATUS_STOPPED.equals(oldRunning)) {
                                    if (TargetInstanceInfo.LIFE_STATUS_STARTED.equals(newRunning)) {
                                        if(statusInfo.getClusterName().equals(targetInfo.getClusterName())){
                                            startInstance(targetInfo);
                                        }else{
                                             // deal with the situation below
                                            // i1 is target instance, i1 belongs to cluster1
                                            // disalbe i1 -> stop i1 -> delete i1
                                            // crearet i1 in cluster2 -> start i1
                                            // we want to i1 is enabled
                                            TargetInstanceInfo newInfo = new TargetInstanceInfo();
                                            newInfo.setClusterName(statusInfo.getClusterName());
                                            newInfo.setInstanceName(instanceName);
                                            newInfo.setCorbalocUrl(getConnectURL(configCtx,
                                                    instanceName));
                                            startInstance(newInfo);
                                        }
                                        
                                    } else if (TargetInstanceInfo.LIFE_STATUS_NO_RESPONSE.equals(newRunning)) {
                                        hangInstance(targetInfo);
                                    }
                                } else if (TargetInstanceInfo.LIFE_STATUS_NO_RESPONSE.equals(oldRunning)) {
                                    if (TargetInstanceInfo.LIFE_STATUS_STARTED.equals(newRunning)) {
                                        startInstance(targetInfo);
                                    } else if (TargetInstanceInfo.LIFE_STATUS_NO_RESPONSE.equals(newRunning)) {
                                        continue;
                                    }
                                }
                            } else if (TargetInstanceInfo.DISPATCH_STATUS_DISABLE.equals(dispatchStauts)) {
                                // if instance is disabled,
                                // only need to set running status
                                targetInfo.setRunningStatus(newRunning);
                            }
                        } // end while

                        // create and start a new instance in target cluster
                        // those new instance are not in allTargetInstances
                        Iterator<String> instances = runningInst.keySet()
                                .iterator();
                        while (instances.hasNext()) {
                            String instanceName = instances.next();
                            InstanceStatusInfo runInfo = runningInst
                                    .get(instanceName);
                            String clusterName = runInfo.getClusterName();

                            // deal with added new instance in target cluster
                            if (targetClusterName.contains(clusterName)
                                    && !allTargetInstances
                                            .containsKey(instanceName)) {
                                TargetInstanceInfo newInfo = new TargetInstanceInfo();
                                newInfo.setClusterName(clusterName);
                                newInfo.setInstanceName(instanceName);
                                newInfo.setCorbalocUrl(getConnectURL(configCtx,
                                        instanceName));
                                startInstance(newInfo);
                            }
                        } // end while
                    }
                    
                    Thread.sleep(10 * 1000);
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        }

    }
    

    class InstanceStatusEventListenerImpl implements
            InstanceStatusEventListener {

        public void updateCurrentMember(InstanceStatusEvent event) {
            if (event == null) {
                return;
            }
            Map<String, InstanceStatusInfo> instanceStatusInfos = event.getInstanceStatusInfos();
            queue.addStatusMap(instanceStatusInfos);

        } // end updateCurrentMember

    } // end class InstanceStatusEventListenerImpl



/**
 * Returns true, if the incoming call is a EJB method call.
 */
private boolean isEjbCall(ServerRequestInfo ri) {
    return ORBManager.isEjbAdapterName(ri.adapter_name())
            && (!ORBManager.isIsACall(ri.operation()));
}

private String createApplicationInfo(String[] adapterNames) {
    StringBuilder applicationInfo = new StringBuilder();
    for(String adapterName : adapterNames){
        applicationInfo.append(adapterName);
        applicationInfo.append("/");
    }
    applicationInfo.deleteCharAt(applicationInfo.length()-1);
    return applicationInfo.toString();
}

}
