/*
 * Copyright (C) 2010 FUJITSU LIMITED
 */

package com.sun.ejb.containers;

import java.net.Socket;
import java.rmi.RemoteException;
import java.util.Hashtable;
import java.util.logging.Level;
import java.util.logging.Logger;

import org.omg.PortableInterceptor.ForwardRequest;
import org.omg.PortableInterceptor.ServerRequestInfo;
import org.omg.PortableInterceptor.ServerRequestInterceptor;

import com.fujitsu.interstage.javaee.admin.event.IiopLBChangeEvent;
import com.fujitsu.interstage.javaee.admin.event.IiopLBChangeEventListener;
import com.sun.corba.ee.impl.folb.InitialIiopDispatchService;
import com.sun.corba.ee.impl.folb.TargetInstanceInfo;
import com.sun.corba.ee.spi.legacy.connection.Connection;
import com.sun.corba.ee.spi.legacy.interceptor.RequestInfoExt;
import com.sun.enterprise.admin.event.AdminEventListenerException;
import com.sun.enterprise.admin.event.AdminEventListenerRegistry;
import com.sun.enterprise.config.ConfigContext;
import com.sun.enterprise.config.ConfigException;
import com.sun.enterprise.config.serverbeans.Cluster;
import com.sun.enterprise.config.serverbeans.ClusterHelper;
import com.sun.enterprise.config.serverbeans.ServerTags;
import com.sun.enterprise.server.ApplicationServer;
import com.sun.enterprise.server.ServerContext;
import com.sun.enterprise.util.ORBManager;

/**
 * This is the implementation of the EJB dispatcher client/server interceptor.
 * This will be called during request/reply invocation path.
 * 
 */
public class EjbIiopServerRequestInterceptor extends org.omg.CORBA.LocalObject
        implements ServerRequestInterceptor {

    // whether the following properties should be static ?????????
    private static Logger _logger = null;
    private static boolean isNoTargetErrorCancel = false; // ??????????????
    private static boolean isRequestLog = false;
    private static IiopLBChangeEventListener iiopLBChangeEvnetListener;
    private static final String REQUEST_TYPE_SERVICE = "SERVICE";
    private static final String REQUEST_TYPE_EJB = "EJB";

    static {
        String loggerName = "javax.enterprise.system.core.naming";
        String loggerResourceBundleName = "com.sun.logging.enterprise.system.core.naming.LogStrings";
        _logger = Logger.getLogger(loggerName, loggerResourceBundleName);

        // Retrieve the definition value from domain.xml.
        try {
            ServerContext serverCtx = ApplicationServer.getServerContext();
            ConfigContext configContext = serverCtx.getConfigContext();
            String instanceName = serverCtx.getInstanceName();
            Cluster cluster = ClusterHelper.getClusterForInstance(
                    configContext, instanceName);

            isRequestLog = cluster.getIiopLoadBalance()
                    .isEjbRequestDispatchLog();
            isNoTargetErrorCancel = true; // ????????????????

        } catch (ConfigException e) {
            // TODO throw the proper exception here
            e.printStackTrace();
        }
    }

    public static final String baseMsg = EjbIiopServerRequestInterceptor.class
            .getName();

    public EjbIiopServerRequestInterceptor() {
        iiopLBChangeEvnetListener = new IiopLBChangeEventListenerImpl();
        AdminEventListenerRegistry
                .addIiopLBChangeEventListener(iiopLBChangeEvnetListener);
    }

    // implementation of the ServerInterceptor interface.
    public void destroy() {
    }

    public String name() {
        return baseMsg;
    }

    public void receive_request_service_contexts(ServerRequestInfo ri)
            throws ForwardRequest {
    }

    public void receive_request(ServerRequestInfo ri) throws ForwardRequest {

        // [03/06/2010 16:19:32.343 +0900] ISJEE: INFO: ISJEE_ED0006: REQUEST
        // ACCEPT "1" "10.10.10.11" "" "EJB" "com.fujitsu.manager.Employee"
        // "create" "82802388684767232_RHome-EJBHome"
        // achieve the log infomation
        // String requestId = String.valueOf(ri.request_id());
        int requestId = ri.request_id();
        String remoteHost = "";
        Connection conn = ((RequestInfoExt) ri).connection();
        if (conn != null) {
            Socket socket = conn.getSocket();
            remoteHost = socket.getInetAddress().toString().substring(1);
        }
        String[] adapterName = ri.adapter_name();
        String instanceName = ""; // this remains empty
        String type = isEjbCall(ri) ? REQUEST_TYPE_EJB : REQUEST_TYPE_SERVICE;
        String operationName = ri.operation();
        String interfaceName = ri.target_most_derived_interface();
        String applicationInfo = adapterName[adapterName.length - 1];

        if (isRequestLog) {
            _logger.log(Level.INFO, "ed.reqeust.log.accept", new Object[] {
                    requestId, remoteHost, instanceName, type, interfaceName,
                    operationName, applicationInfo });
        }

        // only dispatch ejb create operation
        if (!REQUEST_TYPE_EJB.equals(type)) {
            return;
        }

        TargetInstanceInfo info = null;
        org.omg.CORBA.Object reference = null;
        try {
            InitialIiopDispatchService dispatchService = InitialIiopDispatchService
                    .getInstance();
            if (dispatchService != null) {
                info = dispatchService.getNextRotation(adapterName);
                if (info != null) {
                    Hashtable<String, org.omg.CORBA.Object> allReferences = info
                            .getAllReference();
                    reference = allReferences.get(applicationInfo);
                    instanceName = info.getInstanceName();
                }
                if (isRequestLog) {
                    _logger.log(Level.INFO, "ed.request.log.dispatch",
                            new Object[] { requestId, remoteHost, instanceName,
                                    type, interfaceName, operationName,
                                    applicationInfo });
                }
            }

        } catch (RemoteException ex) {
            _logger.log(Level.SEVERE,
                    "EjbServerRequestInterceptor:: receive_request: ", ex);
        }

        if (reference != null) {
            throw new ForwardRequest(reference);
        } else {
            if (isRequestLog) {
                _logger.log(Level.INFO, "ed.target.not.exit", interfaceName);
            }
            throw new org.omg.CORBA.OBJ_ADAPTER(
                    "vmcid: SUN  minor code: 999  completed: No");
        }
    }

    public void send_reply(ServerRequestInfo ri) {
    }

    public void send_exception(ServerRequestInfo ri) throws ForwardRequest {
    }

    public void send_other(ServerRequestInfo ri) throws ForwardRequest {
    }

    /**
     * Returns true, if the incoming call is a EJB method call.
     */
    private boolean isEjbCall(ServerRequestInfo ri) {
        return ORBManager.isEjbAdapterName(ri.adapter_name())
                && (!ORBManager.isIsACall(ri.operation()));
    }

    class IiopLBChangeEventListenerImpl implements IiopLBChangeEventListener {

        public void iiopLBChangeChanged(IiopLBChangeEvent event)
                throws AdminEventListenerException {
            try {
                String attrName = event.getAttrName();
                String to = event.getNewAttrValue();
                if (ServerTags.EJB_REQUEST_DISPATCH_LOG.equals(attrName)) {
                    isRequestLog = Boolean.valueOf(to);
                }
            } catch (Throwable e) {
                throw new AdminEventListenerException(e);
            }

        }
    }

}
