/*
 * Copyright (C) 2010 FUJITSU LIMITED
 */

package com.sun.corba.ee.impl.folb;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.rmi.Remote;
import java.rmi.RemoteException;
import java.util.ArrayList;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.Properties;
import java.util.logging.Level;
import java.util.logging.Logger;

import javax.rmi.PortableRemoteObject;
import javax.rmi.CORBA.Tie;

import org.omg.CORBA.LocalObject;
import org.omg.CORBA.ORB;
import org.omg.CORBA.Policy;
import org.omg.CosNaming.NameComponent;
import org.omg.CosNaming.NamingContext;
import org.omg.CosNaming.NamingContextHelper;
import org.omg.PortableServer.ForwardRequest;
import org.omg.PortableServer.LifespanPolicyValue;
import org.omg.PortableServer.POA;
import org.omg.PortableServer.RequestProcessingPolicyValue;
import org.omg.PortableServer.Servant;
import org.omg.PortableServer.ServantLocator;
import org.omg.PortableServer.ServantRetentionPolicyValue;
import org.omg.PortableServer.ServantLocatorPackage.CookieHolder;

import com.fujitsu.interstage.javaee.admin.event.IiopLBChangeEvent;
import com.fujitsu.interstage.javaee.admin.event.IiopLBChangeEventListener;
import com.sun.corba.ee.impl.orbutil.ORBConstants;
import com.sun.corba.ee.impl.orbutil.ORBUtility;
import com.sun.enterprise.admin.event.AdminEventListenerRegistry;
import com.sun.enterprise.admin.event.InstanceStatusEvent;
import com.sun.enterprise.admin.event.InstanceStatusEventListener;
import com.sun.enterprise.admin.util.JMXConnectorConfig;
import com.sun.enterprise.config.ConfigContext;
import com.sun.enterprise.config.ConfigException;
import com.sun.enterprise.config.serverbeans.Cluster;
import com.sun.enterprise.config.serverbeans.ClusterHelper;
import com.sun.enterprise.config.serverbeans.Config;
import com.sun.enterprise.config.serverbeans.ConfigAPIHelper;
import com.sun.enterprise.config.serverbeans.EjbDispatchTarget;
import com.sun.enterprise.config.serverbeans.IiopListener;
import com.sun.enterprise.config.serverbeans.IiopLoadBalance;
import com.sun.enterprise.config.serverbeans.IiopService;
import com.sun.enterprise.config.serverbeans.PropertyResolver;
import com.sun.enterprise.config.serverbeans.Server;
import com.sun.enterprise.config.serverbeans.ServerHelper;
import com.sun.enterprise.config.serverbeans.ServerTags;
import com.sun.enterprise.server.ApplicationServer;
import com.sun.enterprise.server.ServerContext;
import com.sun.enterprise.util.ORBManager;

/**
 * This class consists of : - Remote interface - Impl of the Remote interface -
 * ServantLocator
 * 
 * This is needed for setting the information about target server instance.
 */
public class InitialIiopDispatchService {

    private static final String IIOP_URL = "iiop:1.2@";
    private static final String CORBALOC = "corbaloc:";
    private static final String DAS_INSTANCE_NAME = "server";
    private static final String EJB_DISPATCHER = "ejb-dispatch";
    private static final String SSL = "SSL";
    private static Object tableLock = new Object();
    private static InitialIiopDispatchService dispatcher = null;
    private static Logger _logger = null;

    // directory to save DISPATCH_FILE
    private static final String workDirectory = "..";
    // log file to save disabled target instances
    // disaabled target still being disable while ejb-dispatcher restarted
    private static final String DISPATCH_FILE = "ejb-dispatch.log";
    private static final String dispatchFileName = workDirectory
            + File.separator + DISPATCH_FILE;;

    private final boolean isDebug = true;
    private boolean isDispatchTargetLog = false;
    private boolean isInitialzed = false;
    private boolean isDispatcher = false;
    private ConfigContext configCtx = null;

    private String myNodeAgentName = null;
    private EjbDispatchTarget[] dispatchTargets = null;

    // all target cluster name
    private List<String> targetClusterName = new ArrayList<String>();

    // adapter and cluster hashtable. key:adapter name value:cluster name
    private Hashtable<String, String> adapterClusterHash = new Hashtable<String, String>();

    // running instance list. key: cluster name value: instances list
    private Hashtable<String, LinkedList<TargetInstanceInfo>> clusterInstancesHash = new Hashtable<String, LinkedList<TargetInstanceInfo>>();

    // all instances list. key: instance name value: instance info
    private Hashtable<String, TargetInstanceInfo> allTargetInstances = new Hashtable<String, TargetInstanceInfo>();

    private InstanceStatusEventListener iseListener = null;
    private IiopLBChangeEventListener ilbcListener = null;

    static {
        String loggerName = "javax.enterprise.system.core.naming";
        String loggerResourceBundleName = "com.sun.logging.enterprise.system.core.naming.LogStrings";
        _logger = Logger.getLogger(loggerName, loggerResourceBundleName);

    }

    public static InitialIiopDispatchService getInstance() {
        return dispatcher;
    }

    /**
     * Constructor of Iiop Dispatch Service.
     * 
     * @param orb
     * @throws IOException
     */
    public InitialIiopDispatchService(ORB orb) {
        if (isDebug) {
            dprint("Bind INITIAL_IDS to CosNaming.");
        }

        bindName(orb);

        // Retrieve the definition value from domain.xml.
        try {
            if (!isInitialzed) {
                init();
            }
            dispatcher = this;
        } catch (ConfigException e) {
            _logger.log(Level.SEVERE, "ed.initialize.error", e);
            return;
        } catch (IOException e) {
            _logger.log(Level.SEVERE, "ed.initialize.error", e);
            return;
        }

        if (isDispatcher) {
            // register runtime MBean DispatcherInfoMBean.
            // it is used for disable, enable, list ejb dispatch target
            // operation
            com.sun.enterprise.ManagementObjectManager mgmtObjManager = com.sun.enterprise.Switch
                    .getSwitch().getManagementObjectManager();
            mgmtObjManager.registerDispatcherInfo();

            // register InstanceStatusEventListener, in order to get latest
            // instance status from nodeAgent
            iseListener = new InstanceStatusEventListenerImpl();

            // TODO AdminEventListenerRegistry don't has
            // addInstaceStatusEventListener() method yet 2010/11/16
            // it will be done when nodeAgent service development finished.
            // AdminEventListenerRegistry.addInstaceStatusEventListener(iseListener);

            // register IiopLBChangeEventListener, in order to get latest
            // ejb-dispatch-target-log
            ilbcListener = new IiopLBChangeEventListenerImpl();
            AdminEventListenerRegistry
                    .addIiopLBChangeEventListener(ilbcListener);
        }

    }

    private void init() throws ConfigException, IOException {

        ServerContext serverCtx = null;
        serverCtx = ApplicationServer.getServerContext();
        configCtx = serverCtx.getConfigContext();

        String instanceName = serverCtx.getInstanceName();
        Server serverObj = ServerHelper
                .getServerByName(configCtx, instanceName);

        if (DAS_INSTANCE_NAME.equals(instanceName)) {
            if (isDebug) {
                dprint("Instance is DAS Instance. DAS Instance can't be an ejb dispatcher.");
            }
            isDispatcher = false;
            isInitialzed = true;
            return;
        }

        // get iiop-load-banlance config info from domain.xml
        Cluster cluster = ClusterHelper.getClusterForInstance(configCtx,
                instanceName);
        IiopLoadBalance iiopLB = cluster.getIiopLoadBalance();
        if (iiopLB != null) {
            String lbMethod = iiopLB.getMethod();
            if (lbMethod != null && EJB_DISPATCHER.equals(lbMethod.trim())) {
                isDispatcher = true;
            } else {
                if (isDebug) {
                    dprint("Becasue of not be ejb-dispatcher, return from InitialIiopDispatchService.init()");
                }
                isInitialzed = true;
                return;
            }

            isDispatchTargetLog = iiopLB.isEjbDispatchTargetLog();
            dispatchTargets = iiopLB.getEjbDispatchTarget();
            if (dispatchTargets != null) {
                for (EjbDispatchTarget target : dispatchTargets) {
                    targetClusterName.add(target.getName());
                }
            }
        }

        if (isDispatchTargetLog) {
            _logger.log(Level.INFO, "ed.initialize");
        }

        myNodeAgentName = serverObj.getNodeAgentRef();
        isInitialzed = true;

        loadDispathTargetClusters();
        loadDisabledInstance();

    }

    /**
     * Load ejb dispatch target clusters from domain.xml.
     */
    private void loadDispathTargetClusters() {

        if (!isInitialzed) {
            try {
                init();
            } catch (ConfigException e) {
                _logger.log(Level.SEVERE, "ed.initialize.error", e);
                e.printStackTrace();
                return;
            } catch (IOException e) {
                _logger.log(Level.SEVERE, "ed.initialize.error", e);
                e.printStackTrace();
                return;
            }
        }

        if (dispatchTargets == null) {
            return;
        }

        for (int i = 0; i < dispatchTargets.length; i++) {
            String clusterName = dispatchTargets[i].getName();

            try {
                addDispatchTargetCluster(clusterName);
            } catch (RemoteException e) {
                _logger.log(Level.SEVERE, "ed.acquire.cluster.info.failed",
                        clusterName);
                return;
            } catch (ConfigException e) {
                _logger.log(Level.SEVERE, "ed.acquire.cluster.info.failed",
                        clusterName);
                return;
            }
        }

    }

    private void addDispatchTargetCluster(String clusterName)
            throws ConfigException, RemoteException {
        Server[] servers = ServerHelper.getServersInCluster(configCtx,
                clusterName);
        if (servers == null) {
            return;
        }
        for (int j = 0; j < servers.length; j++) {
            Server server = servers[j];
            String nodeAgentName = server.getNodeAgentRef();
            String instanceName = server.getName();
            if (!myNodeAgentName.equals(nodeAgentName)) {
                if (isDebug) {
                    dprint("can't add instance "
                            + instanceName
                            + ". Because it has different nodeagent nodeagentName="
                            + nodeAgentName);
                }
                continue;
            }
            // get instance iiop communication host and port
            String configRef = server.getConfigRef();
            Config config = ConfigAPIHelper.getConfigByName(configCtx,
                    configRef);
            IiopService iiopService = config.getIiopService();
            IiopListener[] serverlisteners = iiopService.getIiopListener();
            List<IiopSocketInformation> hostPortList = getHostPortListFromInstance(
                    instanceName, serverlisteners);
            String corbalocUrl = getCorbalocURL(hostPortList);
            addTargetInstance(instanceName, corbalocUrl, clusterName);
        }
    }

    private void addTargetInstance(String instanceName, String corbalocUrl,
            String clusterName) throws ConfigException, RemoteException {

        // prepare instance info
        TargetInstanceInfo insInfo = new TargetInstanceInfo();
        insInfo.setInstanceName(instanceName);
        insInfo.setClusterName(clusterName);
        insInfo.setCorbalocUrl(corbalocUrl);

        _addAdapter(insInfo);
    }

    private List<IiopSocketInformation> getHostPortListFromInstance(
            String instanceName, IiopListener[] serverlisteners)
            throws ConfigException {
        String hostName = getHostNameForServerInstance(instanceName);
        List<IiopSocketInformation> hostPortList = new ArrayList<IiopSocketInformation>();
        for (IiopListener listener : serverlisteners) {
            if (!listener.getId().startsWith(SSL)) {
                String strPort = getResolvedPort(listener, instanceName);
                int port = Integer.parseInt(strPort);
                if (hostName == null || "".equals(hostName.trim())) {
                    hostName = listener.getAddress();
                }
                IiopSocketInformation isi = new IiopSocketInformation();
                isi.setHost(hostName);
                isi.setPort(port);
                hostPortList.add(isi);
            }
        }

        return hostPortList;
    }

    private Hashtable<String, org.omg.CORBA.Object> getAdapterReferenceFromInstance(
            String corbalocUrl) throws RemoteException, Exception {
        Hashtable<String, org.omg.CORBA.Object> referenceOfAdapter = null;
        InitialIiopDispatchService.InitialIDS targetIDS = getIDS(corbalocUrl);
        if (targetIDS != null) {
            referenceOfAdapter = targetIDS.getAllAdapterInformation();
        }
        return referenceOfAdapter;
    }

    /**
     * Load disabled target instances from file "ejb-dispatch.log".
     * 
     * @throws IOException
     * @throws IOException
     */
    private void loadDisabledInstance() throws IOException {

        if (isDebug) {
            dprint("load disabled instances....");
        }
        File dispatchFile = new File(dispatchFileName);
        Properties previousDisabledInst = new Properties();

        if (dispatchFile.exists()) {
            InputStream in = null;
            try {
                in = new FileInputStream(dispatchFile);
                previousDisabledInst.load(in);
            } catch (FileNotFoundException e) {
                _logger.log(Level.SEVERE, "ed.disable.logfile.notfound",
                        dispatchFileName);
                throw e;
            } catch (IOException e) {
                _logger.log(Level.SEVERE, "ed.disable.logfile.write.error",
                        dispatchFileName);
                throw e;
            } finally {
                if (in != null) {
                    in.close();
                }
            }
        } else {
            if (isDebug) {
                dprint(dispatchFileName
                        + " does not exist!!! no need to load disabled instances.");
            }
            // TODO WRITE LOG
            return;
        }

        if (previousDisabledInst == null || previousDisabledInst.size() == 0) {
            return;
        }
        Enumeration<Object> keys = previousDisabledInst.keys();
        while (keys.hasMoreElements()) {
            String instanceName = (String) keys.nextElement();
            disableInstance(instanceName);
        }
    }

    /**
     * Returns ip address from node agent by instance name or null if Exception
     */
    private String getHostNameForServerInstance(String serverName) {
        String host = "";
        try {
            JMXConnectorConfig info = ServerHelper.getJMXConnectorInfo(
                    configCtx, serverName);
            host = info.getHost();
            return host;
        } catch (Throwable e) {
            _logger.log(Level.SEVERE, "ed.acquire.instance.info.error", e);
            return host;
        }
    }

    /**
     * Gets the correct resolved value for the specific instance Without this
     * routine, config context resolves the value to the current running
     * instance
     */
    private String getResolvedPort(IiopListener l, String server)
            throws ConfigException {
        String rawPort = l.getRawAttributeValue("port");
        PropertyResolver pr = new PropertyResolver(configCtx, server);
        return pr.resolve(rawPort);
    }

    private static String getCorbalocURL(List<IiopSocketInformation> list) {

        String corbalocURL = "";
        if (list == null || list.size() == 0) {
            return corbalocURL;
        }
        // convert list into corbaloc url
        for (int i = 0; i < list.size(); i++) {
            if (corbalocURL.equals("")) {
                corbalocURL = IIOP_URL
                        + ((IiopSocketInformation) list.get(i)).getHost()
                                .trim() + ":"
                        + ((IiopSocketInformation) list.get(i)).getPort();
            } else {
                corbalocURL = corbalocURL
                        + ","
                        + IIOP_URL
                        + ((IiopSocketInformation) list.get(i)).getHost()
                                .trim() + ":"
                        + ((IiopSocketInformation) list.get(i)).getPort();
            }
        }
        return CORBALOC + corbalocURL.trim();
    }

    private static InitialIiopDispatchService.InitialIDS getIDS(
            String corbalocURL) throws Exception {
        InitialIiopDispatchService.InitialIDS ids = null;

        org.omg.CORBA.Object ref = ORBManager.getORB().string_to_object(
                corbalocURL);
        NamingContext nctx = NamingContextHelper.narrow(ref);
        NameComponent[] path = { new NameComponent("INITIAL_IDS", "") };
        ids = (InitialIiopDispatchService.InitialIDS) PortableRemoteObject
                .narrow(nctx.resolve(path),
                        InitialIiopDispatchService.InitialIDS.class);

        return ids;
    }

    public void bindName(ORB orb) {
        try {
            POA rootPOA = (POA) orb
                    .resolve_initial_references(ORBConstants.ROOT_POA_NAME);

            Policy[] arr = new Policy[] {
                    rootPOA
                            .create_servant_retention_policy(ServantRetentionPolicyValue.NON_RETAIN),
                    rootPOA
                            .create_request_processing_policy(RequestProcessingPolicyValue.USE_SERVANT_MANAGER),
                    rootPOA
                            .create_lifespan_policy(LifespanPolicyValue.TRANSIENT) };

            POA poa = rootPOA.create_POA(
                    ORBConstants.INITIAL_IIOP_DISPATCH_SERVICE, null, arr);

            InitialIDSServantLocator servantLocator = new InitialIDSServantLocator(
                    orb);
            poa.set_servant_manager(servantLocator);
            poa.the_POAManager().activate();

            byte[] id = new byte[] { 1, 2, 3 };
            org.omg.CORBA.Object provider = poa.create_reference_with_id(id,
                    servantLocator.getType());

            // put object in NameService
            org.omg.CORBA.Object objRef = orb
                    .resolve_initial_references("NameService");
            NamingContext ncRef = NamingContextHelper.narrow(objRef);
            NameComponent nc = new NameComponent(
                    ORBConstants.INITIAL_IIOP_DISPATCH_SERVICE, "");
            NameComponent path[] = { nc };
            ncRef.rebind(path, provider);
        } catch (Exception e) {
            dprint("Exception in InitialGroupInfoService.bindName()==> ", e);
        }
    }

    public void disableTargetInstance(String instanceName)
            throws EJBDispatchException {
        try {

            if (!isInitialzed) {
                init();
            }
        } catch (ConfigException e) {
            throw new EJBDispatchException("Dispatcher init error.");
        } catch (IOException e) {
            throw new EJBDispatchException("Dispatcher init error.");
        }

        disableInstance(instanceName);
        writeDisabledInstance();

    } // disableTargetInstance

    public void enableTargetInstance(String instanceName)
            throws EJBDispatchException {

        try {
            if (!isInitialzed) {
                init();
            }
        } catch (ConfigException e) {
            throw new EJBDispatchException("Dispatcher init error.");
        } catch (IOException e) {
            throw new EJBDispatchException("Dispatcher init error.");
        }
        
        TargetInstanceInfo instanceInfo = null;
        synchronized (tableLock) {
            instanceInfo = allTargetInstances.get(instanceName);
            // TODO STOPPED?
            instanceInfo.setStatus(TargetInstanceInfo.ENABLE);

            String clusterName = instanceInfo.getClusterName();
            LinkedList<TargetInstanceInfo> instanceList = clusterInstancesHash
                    .get(clusterName);
            if (instanceList != null) {
                instanceList.add(instanceInfo);
            } else {
                LinkedList<TargetInstanceInfo> newList = new LinkedList<TargetInstanceInfo>();
                newList.add(instanceInfo);
                clusterInstancesHash.put(clusterName, newList);               
            }

        }
        
        // write enable log
        if (isDispatchTargetLog && instanceInfo != null) {
            Hashtable<String, org.omg.CORBA.Object> references = instanceInfo
                    .getAllReference();
            if (references != null) {
                Enumeration<String> e = references.keys();
                while (e.hasMoreElements()) {
                    String adapterName = e.nextElement();
                    // TODO how to get interface name??
                    String interfaceName = "";
                    _logger.log(Level.INFO, "ed.target.enable", new Object[] {
                            instanceName, interfaceName, adapterName });
                }
            }

        }

        // update disabled instance in ejb-dispatch.log
        writeDisabledInstance();
    } // enableTargetInstance

    public String[][] listTrargetStatus() throws EJBDispatchException {
        try {
            if (!isInitialzed) {
                init();
            }
        } catch (ConfigException e) {
            throw new EJBDispatchException("Dispatcher init error.");
        } catch (IOException e) {
            throw new EJBDispatchException("Dispatcher init error.");
        }
        String[][] result = listTargetStatus();
        return result;
    }

    private void _addAdapter(TargetInstanceInfo insInfo) {

        String corbalocUrl = insInfo.getCorbalocUrl();
        // get adapter name and reference from target instance
        Hashtable<String, org.omg.CORBA.Object> adapterAndReference = null;
        String clusterName = insInfo.getClusterName();
        String instanceName = insInfo.getInstanceName();
        try {
            if (isDispatchTargetLog) {
                _logger.log(Level.INFO, "ed.connect.target", instanceName);
            }
            adapterAndReference = getAdapterReferenceFromInstance(corbalocUrl);
        } catch (Exception e1) {
            if (isDispatchTargetLog) {
                _logger.log(Level.SEVERE, "ed.acquire.instance.info.error",
                        new Object[] { instanceName, e1 });
            }
            e1.printStackTrace();
        }

        synchronized (tableLock) {
            allTargetInstances.put(insInfo.getInstanceName(), insInfo);

            if (adapterAndReference != null && adapterAndReference.size() > 0) {
                insInfo.setAllReference(adapterAndReference);
                insInfo.setStatus(TargetInstanceInfo.ENABLE);
                LinkedList<TargetInstanceInfo> instances = clusterInstancesHash
                        .get(clusterName);
                if (instances != null) {
                    // add to the end
                    instances.add(insInfo);
                } else {
                    LinkedList<TargetInstanceInfo> tempInfo = new LinkedList<TargetInstanceInfo>();
                    tempInfo.add(insInfo);
                    clusterInstancesHash.put(clusterName, tempInfo);
                }

                Enumeration<String> e = adapterAndReference.keys();
                while (e.hasMoreElements()) {
                    String adapterName = e.nextElement();
                    if (adapterClusterHash.containsKey(adapterName)) {
                        // TODO
                        // if(!adapterClusterHash.get(adapterName).equals(clusterName))
                        // throw an exception? write log?
                        continue;
                    }
                    adapterClusterHash.put(adapterName, clusterName);

                    if (isDispatchTargetLog) {
                        // TODO: how to get interface name??
                        String interfaceName = "";
                        _logger.log(Level.INFO, "ed.target.add", new Object[] {
                                instanceName, interfaceName, adapterName });
                    }
                }

            } else {
                insInfo.setStatus(TargetInstanceInfo.STOPPED);
                if (isDebug) {
                    dprint("can not get ejb applications' references and adpater names from instance. name="
                            + insInfo.getInstanceName());
                }
            }

            if (isDebug) {
                showTables();
            }
        }
    }

    private void showTables() {

        if (targetClusterName == null || targetClusterName.size() == 0) {
            System.out.println("targetClusterName is empty");
        } else {
            System.out
                    .println("---------- values in targetClusterNames -----------------");
            for (String cluster : targetClusterName) {
                System.out.println("cluster=" + cluster);
            }
        }

        if (adapterClusterHash == null || adapterClusterHash.size() == 0) {
            System.out.println("adapterHashtable is empety");
        } else {
            Enumeration<String> e1 = adapterClusterHash.keys();
            System.out.println("---------- values in adapterHashtable:"
                    + adapterClusterHash.size());
            while (e1.hasMoreElements()) {
                String key1 = e1.nextElement();
                System.out.println("key,value=" + key1 + ","
                        + adapterClusterHash.get(key1));
            }
        }

        if (clusterInstancesHash == null || clusterInstancesHash.size() == 0) {
            System.out.println("instanceHashtable is empety");
        } else {
            Enumeration<String> e1 = clusterInstancesHash.keys();
            System.out.println("values in instanceHashtable:"
                    + clusterInstancesHash);
            while (e1.hasMoreElements()) {
                String key1 = e1.nextElement();
                System.out.println("key,value=" + key1 + ","
                        + clusterInstancesHash.get(key1));
            }
        }

        if (allTargetInstances == null || allTargetInstances.size() == 0) {
            System.out.println("allTargetInstances is empety");
        } else {
            Enumeration<String> e1 = allTargetInstances.keys();
            System.out.println("values in allTargetInstances:"
                    + allTargetInstances);
            while (e1.hasMoreElements()) {
                String key1 = e1.nextElement();
                System.out.println("key,value=" + key1 + ","
                        + allTargetInstances.get(key1));
            }
        }

    }

    private void _deleteAdapter(String clusterName) {
        if (isDebug) {
            dprint("delete target cluster=" + clusterName);
        }
        synchronized (tableLock) {
            // delete from targetClusterName
            targetClusterName.remove(clusterName);
            // delete from clusterInstancesHash
            clusterInstancesHash.remove(clusterName);

            // delete from adapter cluster Hashtable
            Enumeration<String> e = adapterClusterHash.keys();
            while (e.hasMoreElements()) {
                String adapterName = (String) e.nextElement();
                String value = adapterClusterHash.get(adapterName);
                if (value.equals(clusterName)) {
                    adapterClusterHash.remove(adapterName);
                }
            }

            // delete from allTargetInstance
            Enumeration<String> insName = allTargetInstances.keys();
            while (insName.hasMoreElements()) {
                String name = (String) insName.nextElement();
                TargetInstanceInfo info = allTargetInstances.get(name);
                if (clusterName.equals(info.getClusterName())) {
                    allTargetInstances.remove(name);
                    if (isDispatchTargetLog) {
                        _logger.log(Level.INFO, "ed.target.delete", name);
                    }
                }
            }
        } // end of synchronized

    }

    private boolean disableInstance(String instanceName) {
        boolean result = false;
        synchronized (tableLock) {
            TargetInstanceInfo instanceInfo = allTargetInstances
                    .get(instanceName);
            if (instanceInfo != null) {
                if (TargetInstanceInfo.ENABLE.equals(instanceInfo.getStatus())) {
                    instanceInfo.setStatus(TargetInstanceInfo.DISABLE);
                } else if (TargetInstanceInfo.STOPPED.equals(instanceInfo
                        .getStatus())) {
                    instanceInfo.setStatus(TargetInstanceInfo.DISABLE_STOPPED);
                }

                // remove instance info from cluster instance hashtable
                String clusterName = instanceInfo.getClusterName();
                LinkedList<TargetInstanceInfo> instanceList = clusterInstancesHash
                        .get(clusterName);
                if (instanceList != null) {
                    result = instanceList.remove(instanceInfo);
                }
            }

        }

        if (isDispatchTargetLog) {
            _logger.log(Level.INFO, "ed.target.disable", instanceName);
        }
        return result;
    }

    /**
     * Get all target instance's status.
     * 
     * @return
     */
    private String[][] listTargetStatus() {
        if (allTargetInstances == null) {
            return null;
        }
        String[][] result = null;
        Enumeration<String> keys = null;

        int clusterNum = 0;
        synchronized (tableLock) {
            clusterNum = allTargetInstances.size();
            keys = allTargetInstances.keys();
        }
        result = new String[clusterNum][3];

        // how many information,list command instance will show
        int elementNum = 3;
        int i = 0;
        while (keys.hasMoreElements()) {
            String key = keys.nextElement();
            TargetInstanceInfo info = allTargetInstances.get(key);
            int j = 0;
            String[] instance = new String[elementNum];
            instance[j] = info.getClusterName();
            instance[++j] = info.getInstanceName();
            String status = info.getStatus();
            // disabled and stop instance is disabled instance
            if (TargetInstanceInfo.DISABLE_STOPPED.equals(status)) {
                status = TargetInstanceInfo.DISABLE;
            }
            instance[++j] = status;
            result[i] = instance;
            i++;
        }

        return result;
    }

    /**
     * Set isDispatchTargetLog.
     * 
     * @param logOption
     */
    public void setDispatchLog(boolean logOption) {
        isDispatchTargetLog = logOption;
    }

    /**
     * Select an appropriate instance for an EJB create operation.
     * 
     * @param adapterName
     * @return
     * @throws RemoteException
     */
    public TargetInstanceInfo getNextRotation(String[] adapterName)
            throws RemoteException {

        if (!isInitialzed) {
            try {
                init();
            } catch (ConfigException e) {
                e.printStackTrace();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }

        TargetInstanceInfo selected = null;
        if (adapterName == null || adapterName.length == 0) {
            return selected;
        }
        String name = adapterName[adapterName.length - 1];

        synchronized (tableLock) {
            String clusterName = adapterClusterHash.get(name);
            LinkedList<TargetInstanceInfo> instanceList = clusterInstancesHash
                    .get(clusterName);
            if (instanceList != null) {
                // retrieves and remove first element
                selected = instanceList.poll();
                // append selected element to the end
                instanceList.add(selected);
            }
        }

        if (isDebug && selected != null) {
            dprint("dispatch instance is " + selected.getInstanceName());
        }
        return selected;
    }

    static void dprint(String msg) {
        ORBUtility.dprint("InitialIiopDispatchService", msg);
    }

    static void dprint(String msg, Throwable t) {
        dprint(msg);
        dprint(t.toString());
    }

    private void writeDisabledInstance() {
        if (allTargetInstances == null || allTargetInstances.size() == 0) {
            if (isDebug) {
                dprint("allTargetInstances in empty.");
            }
            return;
        }

        Properties targetProps = new Properties();
        Enumeration<String> keys = null;
        synchronized (tableLock) {
            keys = allTargetInstances.keys();
        }

        while (keys != null && keys.hasMoreElements()) {
            String instanceName = keys.nextElement();
            TargetInstanceInfo info = allTargetInstances.get(instanceName);
            // only write disabled instances' name and cluster name to log file
            if (TargetInstanceInfo.DISABLE.equals(info.getStatus())
                    || TargetInstanceInfo.DISABLE_STOPPED.equals(info
                            .getStatus())) {
                targetProps.put(instanceName, info.getClusterName());
            }
        }

        OutputStream output = null;
        try {
            File f = new File(dispatchFileName);
            if (!f.exists()) {
                f.createNewFile();
            }
            output = new FileOutputStream(f);
            targetProps.store(output, null);
        } catch (IOException e) {
            // TODO:
            System.out
                    .println("ISJEE: WARNING: xxxxxxxxxxxx ISJEE_XXXXXXXX:IIOP Dispatcher cannot write information."
                            + dispatchFileName);
            e.printStackTrace();
        } finally {
            if (output != null) {
                try {
                    output.close();
                } catch (IOException ioe) {
                }
            }
        }
    }

    public interface InitialIDS extends Remote {

        public Hashtable<String, org.omg.CORBA.Object> getAllAdapterInformation()
                throws RemoteException;

        // public String[][] listTrargetStatus() throws
        // RemoteException,EJBDispatchException;

        public void addTargetCluster(String clusterName)
                throws RemoteException, EJBDispatchException;

        public void deleteTargetCluster(String clusterName)
                throws RemoteException, EJBDispatchException;

        // public void disableTargetInstance(String instanceName) throws
        // RemoteException,EJBDispatchException;
        //		
        // public void enableTargetInstance(String instanceName) throws
        // RemoteException,EJBDispatchException;

    } // InitialIDS class

    public class InitialIDSImpl extends PortableRemoteObject implements
            InitialIDS {

        private ORB orb;

        public InitialIDSImpl(ORB orb) throws RemoteException {
            super();
            this.orb = orb;
        }

        public Hashtable<String, org.omg.CORBA.Object> getAllAdapterInformation()
                throws RemoteException {
            if (isDebug) {
                dprint("Get EJB adapter name and reference from dispatch target instance.");
            }
            IiopDispatchServiceClient idsc = IiopDispatchServiceClient
                    .getInstance();
            return idsc.getAllAdapterInformation();
        }

        public void addTargetCluster(String clusterName) throws RemoteException, EJBDispatchException {

                try {
                    if (!isInitialzed) {
                        init();
                    }
                } catch (ConfigException e1) {
                    throw new EJBDispatchException("Dispatcher init error.");
                } catch (IOException e1) {
                    throw new EJBDispatchException("Dispatcher init error.");
                }

                if (clusterName == null || "".equals(clusterName)) {
                    throw new EJBDispatchException(
                            "The operator cluster can not be empty.");
                } else if (DAS_INSTANCE_NAME.equals(clusterName)) {
                    throw new EJBDispatchException("Server can not be dispatch target!");
                } else if (clusterInstancesHash.containsKey(clusterName)) {
                    throw new EJBDispatchException("The operator cluster "
                            + clusterName + "is already exist.");
                }


            try {
                if (isDebug) {
                    dprint("add a new target cluster=" + clusterName);
                }
                if (!targetClusterName.contains(clusterName)) {
                    targetClusterName.add(clusterName);
                }
                addDispatchTargetCluster(clusterName);
            } catch (RemoteException e) {
               throw e;
            } catch (ConfigException e) {
               throw new EJBDispatchException(e);
            }

        }

        public void deleteTargetCluster(String clusterName) throws EJBDispatchException {
            try {
                if (!isInitialzed) {
                    init();
                }
            } catch (ConfigException e) {
                throw new EJBDispatchException("Dispatcher init error.");
            } catch (IOException e) {
                throw new EJBDispatchException("Dispatcher init error.");
            }

            if (clusterName == null || "".equals(clusterName)) {
                throw new EJBDispatchException(
                        "The operator cluster can not be empty.");
            } else if (DAS_INSTANCE_NAME.equals(clusterName)) {
                throw new EJBDispatchException("Server can not be dispatch target!");
            } else if (!targetClusterName.contains(clusterName)) {
                throw new EJBDispatchException("The operator cluster " + clusterName
                        + " is not dispatch target.");
            }

            _deleteAdapter(clusterName);
            writeDisabledInstance();

        } // deleteTargetCluster method

    } // InitialIDSImpl class

    public class InitialIDSServantLocator extends LocalObject implements
            ServantLocator {
        private Servant servant;
        private InitialIDSImpl impl = null;

        public InitialIDSServantLocator(ORB orb) {
            try {
                impl = new InitialIDSImpl(orb);
            } catch (Exception exc) {
                dprint("Exception in new InitialIDSServantLocator==> ", exc);
            }

            Tie tie = com.sun.corba.ee.spi.orb.ORB.class.cast(orb)
                    .getPresentationManager().getTie();
            tie.setTarget(impl);
            servant = Servant.class.cast(tie);
        }

        public String getType() {
            return servant._all_interfaces(null, null)[0];
        }

        public synchronized Servant preinvoke(byte[] oid, POA adapter,
                String operation, CookieHolder the_cookie)
                throws ForwardRequest {
            return servant;
        }

        public void postinvoke(byte[] oid, POA adapter, String operation,
                Object the_cookie, Servant the_servant) {
        }
    }

    class InstanceStatusEventListenerImpl implements
            InstanceStatusEventListener {

        public void updateCurrentMember(InstanceStatusEvent event) {

            if (event == null) {
                return;
            }

            // deal with new instance in target cluster
            // those new instance are not in all target instance hashtable
            Map<String, String> runningInst = event.getRunningInstance();
            Iterator<String> instances = runningInst.keySet().iterator();
            while (instances.hasNext()) {
                String instanceName = instances.next();
                String clusterName = runningInst.get(instanceName);

                synchronized (tableLock) {
                    // deal with added new instance in target cluster
                    if (targetClusterName.contains(clusterName)
                            && !allTargetInstances.containsKey(instanceName)) {
                        TargetInstanceInfo newInfo = new TargetInstanceInfo();
                        newInfo.setClusterName(clusterName);
                        newInfo.setInstanceName(instanceName);
                        startInstance(newInfo);
                    }
                }

            }

            // update instance info in all target instance hashtable
            synchronized (tableLock) {
                Enumeration<String> keys = allTargetInstances.keys();
                while (keys.hasMoreElements()) {
                    String instanceName = keys.nextElement();
                    TargetInstanceInfo oldInfo = allTargetInstances
                            .get(instanceName);
                    String oldStatus = oldInfo.getStatus();
                    boolean isRunning = runningInst.containsKey(instanceName);

                    if (TargetInstanceInfo.DISABLE.equals(oldStatus)) {
                        if (isRunning) {
                            // do nothing
                        } else {
                            stopInstance(oldInfo);
                        }
                    } else if (TargetInstanceInfo.ENABLE.equals(oldStatus)) {
                        if (isRunning) {
                            // do nothing
                        } else {
                            stopInstance(oldInfo);
                        }
                    } else if (TargetInstanceInfo.STOPPED.equals(oldStatus)) {
                        if (isRunning) {
                            startInstance(oldInfo);
                        } else {
                            // do nothing
                        }
                    } else if (TargetInstanceInfo.DISABLE_STOPPED
                            .equals(oldStatus)) {
                        if (isRunning) {
                            // get reference from instance
                            startInstance(oldInfo);
                        } else {
                            // do nothing
                        }
                    }
                } // end while
            } // end synchronized

        } // end updateCurrentMember

        private void stopInstance(TargetInstanceInfo oldInfo) {
            if (oldInfo == null) {
                return;
            }
            String status = oldInfo.getStatus();
            String clusterName = oldInfo.getClusterName();

            synchronized (tableLock) {
                // remove from instanceHashtable
                if (TargetInstanceInfo.ENABLE.equals(status)) {
                    // instance info in allTargetInstaceInfo will be stopped
                    oldInfo.setStatus(TargetInstanceInfo.STOPPED);
                    LinkedList<TargetInstanceInfo> list = clusterInstancesHash
                            .get(clusterName);
                    if (list != null) {
                        list.remove(oldInfo);
                    }

                } else if (TargetInstanceInfo.DISABLE.equals(status)) {
                    // disabled and stop status
                    oldInfo.setStatus(TargetInstanceInfo.DISABLE_STOPPED);
                }
            }
        }

        private void startInstance(TargetInstanceInfo oldInfo) {
            if (oldInfo == null) {
                return;
            }
            String instanceName = oldInfo.getInstanceName();
            String clusterName = oldInfo.getClusterName();
            Server server = null;
            try {
                server = ServerHelper.getServerByName(configCtx, instanceName);

                String configRef = server.getConfigRef();
                Config config = ConfigAPIHelper.getConfigByName(configCtx,
                        configRef);
                IiopService iiopService = config.getIiopService();
                IiopListener[] serverlisteners = iiopService.getIiopListener();
                List<IiopSocketInformation> hostPortList = getHostPortListFromInstance(
                        instanceName, serverlisteners);
                String corbalocUrl = getCorbalocURL(hostPortList);
                addTargetInstance(instanceName, corbalocUrl, clusterName);

            } catch (ConfigException e) {
                _logger.log(Level.SEVERE, "ed.connect.target.error");
                e.printStackTrace();
            } catch (RemoteException e) {
                _logger.log(Level.SEVERE, "ed.connect.target.error");
                e.printStackTrace();
            }

            oldInfo.setStatus(TargetInstanceInfo.ENABLE);
        }

    } // end class InstanceStatusEventListenerImpl

    class IiopLBChangeEventListenerImpl implements IiopLBChangeEventListener {

        public void iiopLBChangeChanged(IiopLBChangeEvent event) {
            String attrName = event.getAttrName();
            String to = event.getNewAttrValue();
            if (ServerTags.EJB_DISPATCH_TARGET_LOG.equals(attrName)) {
                setDispatchLog(Boolean.valueOf(to));
            }
        }
    } // end class IiopLBChangeEventListenerImpl

    public InitialIiopDispatchService() {
        targetClusterName.add("Cluster1");
        targetClusterName.add("Cluster2");
        targetClusterName.add("Cluster3");

        adapterClusterHash.put("ejb11", targetClusterName.get(0));
        adapterClusterHash.put("ejb12", targetClusterName.get(0));
        adapterClusterHash.put("ejb21", targetClusterName.get(1));
        adapterClusterHash.put("ejb22", targetClusterName.get(1));
        adapterClusterHash.put("ejb31", targetClusterName.get(2));
        adapterClusterHash.put("ejb32", targetClusterName.get(2));

        // TaregetInstanc
        // instanceHashtable.put(targetClusterName.get(0), value);

    }
}
